#!/bin/bash
#SBATCH -J zidan_hubbard
#SBATCH -o ./%x.%j.out
#SBATCH -e ./%x.%j.err
#SBATCH -D ./
#SBATCH --mail-type=NONE
#SBATCH --time=02:30:00
#SBATCH --no-requeue
#SBATCH --export=NONE
#SBATCH --get-user-env
#SBATCH --account=pn25mo
#SBATCH --partition=micro
#other (queues) partitions: micro, general, large or fat
#SBATCH --nodes=4
#SBATCH --ntasks-per-node=40

delta=0.00153174  #(0.05 A)

#Important
module load slurm_setup

EXEC=/dss/dsshome1/06/di73taf3/CODES/espresso/version/qe-7.2/bin

function relax_run()
{
cat << THEEND
&CONTROL
  calculation = 'vc-relax'
  etot_conv_thr =   1.4000000000d-04
  forc_conv_thr =   1.0000000000d-04
  outdir = './out_$i/'
  prefix = 'pwscf'
  pseudo_dir = './timon_PPs/'
  tprnfor = .true.
  tstress = .true.
  verbosity = 'high'
  nstep=500
/
&SYSTEM
  degauss =   0.0146997236
  ecutrho =   4.8000000000d+02
  ecutwfc =   6.0000000000d+01
  ibrav = 4
  A=2.9685000000
  B=2.9685000000
  C=42.6425670000
  cosAB=0.50000000
  cosAC=0
  cosBC=0
  nat = 14
  nosym = .false.
  nspin = 2
  ntyp = 4
  occupations = 'smearing'
  smearing = 'cold'
  starting_magnetization(1) =   1.0000000000d-01
  starting_magnetization(2) =   3.8461538462d-01
  starting_magnetization(3) =   1.0000000000d-01
  starting_magnetization(4) =   3.8461538462d-01
  vdw_corr='grimme-d2'
/
&ELECTRONS
  conv_thr =   1.000000000d-07
  electron_maxstep = 150
  mixing_beta =  0.25
/
&IONS
/
&CELL
cell_dofree='2Dxy'
press_conv_thr=0.1
/
ATOMIC_SPECIES
N      14.0067 N_ONCV_PBE_sr.upf
Nb     92.90638 Nb_ONCV_PBE_sr.upf
Si     28.0855 Si_ONCV_PBE_sr.upf
Ta     180.94788 Ta_ONCV_PBE_sr.upf
ATOMIC_POSITIONS crystal
Nb           0.0000000000       0.0000000000     `echo  0.2692439200 $i $delta | awk '{print $1 + $2*$3}'`
Ta           0.6666670000       0.3333330000     `echo  0.4987259976 $i $delta | awk '{print $1 - $2*$3}'`
N            0.6666670000       0.3333330000     `echo  0.3510033516 $i $delta | awk '{print $1 + $2*$3}'`
N            0.6666670000       0.3333330000     `echo  0.1873448315 $i $delta | awk '{print $1 + $2*$3}'` 
N            0.3333330000       0.6666670000     `echo  0.2397032134 $i $delta | awk '{print $1 + $2*$3}'`
N            0.3333330000       0.6666670000     `echo  0.2987829357 $i $delta | awk '{print $1 + $2*$3}'`
N            0.3333330000       0.6666670000     `echo  0.5805009914 $i $delta | awk '{print $1 + $2*$3}'`
N            0.3333330000       0.6666670000     `echo  0.4171682744 $i $delta | awk '{print $1 + $2*$3}'`
N            0.0000000000       0.0000000000     `echo  0.5282068943 $i $delta | awk '{print $1 + $2*$3}'`
N            0.0000000000       0.0000000000     `echo  0.4692927027 $i $delta | awk '{print $1 - $2*$3}'`
Si           0.3333330000       0.6666670000     `echo  0.1987787927 $i $delta | awk '{print $1 - $2*$3}'`
Si           0.3333330000       0.6666670000     `echo  0.3396660428 $i $delta | awk '{print $1 - $2*$3}'`
Si           0.0000000000       0.0000000000     `echo  0.4282949616 $i $delta | awk '{print $1 - $2*$3}'`
Si           0.0000000000       0.0000000000     `echo  0.5692010904 $i $delta | awk '{print $1 - $2*$3}'`
K_POINTS automatic
20 20 1 0 0 0
HUBBARD (ortho-atomic)
  U Nb-4d 3.4631
  U Ta-5d 3.2306
THEEND
}

for i in 0
do
	relax_run > pw_relax_test_$i.in
	mpiexec -n $SLURM_NTASKS $EXEC/pw.x -npool 8 -i pw_relax_test_$i.in > pw_relax_test_$i.out
done

exit 4

rm lat_par.txt
touch lat_pat.txt

mkdir ./out_1
cp ./out_0/pwscf.save/charge-density.dat ./out_1/pwscf/save/

for i in 1 2 3 4
do
  relax_run > pw_relax_test_$i.in
  mpiexec -n $SLURM_NTASKS $EXEC/pw.x -npool 8 -i pw_relax_test_$i.in > pw_relax_test_$i.out
  r=$(($i+1))
  mkdir ./out_$r/
  cp ./out_$i/pwscf.save/charge-density.dat ./out_$r/pwscf.save/
  echo "SHITCKO POROBENO"
done

mkdir ./out_-1
cp ./out_0/pwscf.save/charge-density.dat ./out_-1/pwscf/save/


for i in -1 -2 -3 -4
do
  relax_run > pw_relax_test_$i.in
  mpiexec -n $SLURM_NTASKS $EXEC/pw.x -npool 8 -i pw_relax_test_$i.in > pw_relax_test_$i.out
  r=$(($i-1))
  mkdir ./out_$r/
  cp ./out_$i/pwscf.save/charge-density.dat ./out_$r/pwscf.save/
  echo "SHITCKO POROBENO"
done

